==> huawei_iap-5.0.2%2B301.tar.gz: example/lib/HomePage.dart <==
/*
    Copyright 2020-2021. Huawei Technologies Co., Ltd. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License")
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        https://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/
import 'package:flutter/material.dart';
import 'package:huawei_iap_example/CustomWidgets/Consumables.dart';
import 'package:huawei_iap_example/CustomWidgets/NonConsumables.dart';
import 'package:huawei_iap_example/CustomWidgets/Subscriptions.dart';

class HomePage extends StatefulWidget {
  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: const Text('Huawei IAP Demo'),
          centerTitle: true,
          backgroundColor: Colors.red,
        ),
        body: SingleChildScrollView(
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              Consumables(),
              Padding(
                padding: const EdgeInsets.symmetric(vertical: 20.0),
                child: Divider(
                  thickness: 2,
                  color: Colors.grey[400],
                ),
              ),
              NonConsumables(),
              Padding(
                padding: const EdgeInsets.symmetric(vertical: 20.0),
                child: Divider(
                  thickness: 2,
                  color: Colors.grey[400],
                ),
              ),
              Subscriptions(),
            ],
          ),
        ));
  }
}

==> huawei_iap-6.4.0%2B301.tar.gz: example/lib/HomePage.dart <==
/*
    Copyright 2020-2022. Huawei Technologies Co., Ltd. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License")
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        https://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

import 'package:flutter/material.dart';

import './CustomWidgets/Consumables.dart';
import './CustomWidgets/NonConsumables.dart';
import './CustomWidgets/Subscriptions.dart';

class HomePage extends StatefulWidget {
  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: const Text('Huawei IAP Demo'),
          centerTitle: true,
          backgroundColor: Colors.red,
        ),
        body: SingleChildScrollView(
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              Consumables(),
              Padding(
                padding: const EdgeInsets.symmetric(vertical: 20.0),
                child: Divider(
                  thickness: 2,
                  color: Colors.grey[400],
                ),
              ),
              NonConsumables(),
              Padding(
                padding: const EdgeInsets.symmetric(vertical: 20.0),
                child: Divider(
                  thickness: 2,
                  color: Colors.grey[400],
                ),
              ),
              Subscriptions(),
            ],
          ),
        ));
  }
}
